Enum font_kit::canvas::Format [−][src]
pub enum Format {
Rgba32,
Rgb24,
A8,
}The image format for the canvas.
Variants
Rgba32Premultiplied R8G8B8A8, little-endian.
Rgb24R8G8B8, little-endian.
A8A8.
Methods
impl Format[src]
impl Formatpub fn bits_per_pixel(self) -> u8[src]
pub fn bits_per_pixel(self) -> u8Returns the number of bits per pixel that this image format corresponds to.
pub fn components_per_pixel(self) -> u8[src]
pub fn components_per_pixel(self) -> u8Returns the number of color channels per pixel that this image format corresponds to.
pub fn bits_per_component(self) -> u8[src]
pub fn bits_per_component(self) -> u8Returns the number of bits per color channel that this image format contains.
pub fn bytes_per_pixel(self) -> u8[src]
pub fn bytes_per_pixel(self) -> u8Returns the number of bytes per pixel that this image format corresponds to.