Enum font_kit::handle::Handle [−][src]
pub enum Handle {
Path {
path: PathBuf,
font_index: u32,
},
Memory {
bytes: Arc<Vec<u8>>,
font_index: u32,
},
}Expand description
Encapsulates the information needed to locate and open a font.
This is either the path to the font or the raw in-memory font data.
To open the font referenced by a handle, use a loader.
Variants
A font on disk referenced by a path.
Show fields
A font in memory.
Show fields
Implementations
Creates a new handle from a path.
font_index specifies the index of the font to choose if the path points to a font
collection. If the path points to a single font file, pass 0.
Creates a new handle from raw TTF/OTF/etc. data in memory.
font_index specifies the index of the font to choose if the memory represents a font
collection. If the memory represents a single font file, pass 0.
A convenience method to load this handle with the default loader, producing a Font.