Enum font_kit::hinting::HintingOptions [−][src]
Specifies how hinting (grid fitting) is to be performed (or not performed) for a glyph.
This affects both outlines and rasterization.
Variants
NoneNo hinting is performed unless absolutely necessary to assemble the glyph.
This corresponds to what macOS and FreeType in its "no hinting" mode do.
Vertical(f32)Hinting is performed only in the vertical direction. The specified point size is used for grid fitting.
This corresponds to what DirectWrite and FreeType in its light hinting mode do.
VerticalSubpixel(f32)Hinting is performed only in the vertical direction, and further tweaks are applied to make subpixel antialiasing look better. The specified point size is used for grid fitting.
This matches DirectWrite, GDI in its ClearType mode, and FreeType in its LCD hinting mode.
Full(f32)Hinting is performed in both horizontal and vertical directions. The specified point size is used for grid fitting.
This corresponds to what GDI in non-ClearType modes and FreeType in its normal hinting mode do.
Methods
impl HintingOptions[src]
impl HintingOptionspub fn grid_fitting_size(&self) -> Option<f32>[src]
pub fn grid_fitting_size(&self) -> Option<f32>Returns the point size that will be used for grid fitting, if any.