Struct font_kit::outline::Contour [−][src]
pub struct Contour {
pub positions: Vec<Vector2F>,
pub flags: Vec<PointFlags>,
}Expand description
A single curve or subpath within a glyph outline.
Fields
positions: Vec<Vector2F>Positions of each point.
This must have the same length as the flags field.
flags: Vec<PointFlags>Flags that specify what type of point the corresponding position represents.
This must have the same length as the positions field.
Implementations