Struct font_kit::outline::OutlineBuilder [−][src]
pub struct OutlineBuilder { /* fields omitted */ }Expand description
Accumulates Bézier path rendering commands into an Outline structure.
Implementations
Creates a new empty OutlineBuilder.
Consumes this outline builder and returns the resulting outline.
Resets the outline builder and returns the old outline.