Struct font_kit::properties::Properties [−][src]
Properties that specify which font in a family to use: e.g. style, weight, and stretchiness.
This object supports a method chaining style for idiomatic initialization; e.g.
println!("{:?}", Properties::new().style(Style::Italic));
Fields
style: StyleThe font style, as defined in CSS.
weight: WeightThe font weight, as defined in CSS.
stretch: StretchThe font stretchiness, as defined in CSS.
Implementations
Initializes a property set to its default values: normal style, normal weight, and normal stretchiness.
Sets the value of the style property and returns this property set for method chaining.
Sets the value of the weight property and returns this property set for method chaining.
Sets the value of the stretch property and returns this property set for method chaining.