Struct font_kit::sources::mem::MemSource[][src]

pub struct MemSource { /* fields omitted */ }

A source that keeps fonts in memory.

Methods

impl MemSource
[src]

Creates a new memory source that contains the given set of font handles.

The fonts referenced by the handles are eagerly loaded into memory.

Returns the names of all families installed on the system.

Looks up a font family by name and returns the handles of all the fonts in that family.

FIXME(pcwalton): Case-insensitive comparison.

Selects a font by PostScript name, which should be a unique identifier.

The default implementation, which is used by the DirectWrite and the filesystem backends, does a brute-force search of installed fonts to find the one that matches.

Performs font matching according to the CSS Fonts Level 3 specification and returns the handle.