Enum font_kit::handle::Handle [−][src]
pub enum Handle {
Path {
path: PathBuf,
font_index: u32,
},
Memory {
bytes: Arc<Vec<u8>>,
font_index: u32,
},
}Encapsulates the information needed to locate and open a font.
This is either the path to the font or the raw in-memory font data.
To open the font referenced by a handle, use a loader.
Variants
PathA font on disk referenced by a path.
Fields of Path
path: PathBuf | The path to the font. |
font_index: u32 | The index of the font, if the path refers to a collection. If the path refers to a single font, this value will be 0. |
MemoryA font in memory.
Fields of Memory
bytes: Arc<Vec<u8>> | The raw TrueType/OpenType/etc. data that makes up this font. |
font_index: u32 | The index of the font, if the memory consists of a collection. If the memory consists of a single font, this value will be 0. |
Methods
impl Handle[src]
impl Handlepub fn from_path(path: PathBuf, font_index: u32) -> Handle[src]
pub fn from_path(path: PathBuf, font_index: u32) -> HandleCreates a new handle from a path.
font_index specifies the index of the font to choose if the path points to a font
collection. If the path points to a single font file, pass 0.
pub fn from_memory(bytes: Arc<Vec<u8>>, font_index: u32) -> Handle[src]
pub fn from_memory(bytes: Arc<Vec<u8>>, font_index: u32) -> HandleCreates a new handle from raw TTF/OTF/etc. data in memory.
font_index specifies the index of the font to choose if the memory represents a font
collection. If the memory represents a single font file, pass 0.
pub fn load(&self) -> Result<Font, FontLoadingError>[src]
pub fn load(&self) -> Result<Font, FontLoadingError>A convenience method to load this handle with the default loader, producing a Font.