Struct font_kit::properties::Properties [−][src]
Properties that specify which font in a family to use: e.g. style, weight, and stretchiness.
This object supports a method chaining style for idiomatic initialization; e.g.
println!("{:?}", Properties::new().style(Style::Italic));
Fields
style: Style
The font style, as defined in CSS.
weight: Weight
The font weight, as defined in CSS.
stretch: Stretch
The font stretchiness, as defined in CSS.
Methods
impl Properties[src]
impl Propertiespub fn new() -> Properties[src]
pub fn new() -> PropertiesInitializes a property set to its default values: normal style, normal weight, and normal stretchiness.
pub fn style(&mut self, style: Style) -> &mut Properties[src]
pub fn style(&mut self, style: Style) -> &mut PropertiesSets the value of the style property and returns this property set for method chaining.
pub fn weight(&mut self, weight: Weight) -> &mut Properties[src]
pub fn weight(&mut self, weight: Weight) -> &mut PropertiesSets the value of the weight property and returns this property set for method chaining.
pub fn stretch(&mut self, stretch: Stretch) -> &mut Properties[src]
pub fn stretch(&mut self, stretch: Stretch) -> &mut PropertiesSets the value of the stretch property and returns this property set for method chaining.