Trait font_kit::source::Source[][src]

pub trait Source {
    fn all_families(&self) -> Result<Vec<String>, SelectionError>;
fn select_family_by_name(
        &self,
        family_name: &str
    ) -> Result<FamilyHandle, SelectionError>; fn select_by_postscript_name(
        &self,
        postscript_name: &str
    ) -> Result<Handle, SelectionError> { ... }
fn select_best_match(
        &self,
        family_names: &[FamilyName],
        properties: &Properties
    ) -> Result<Handle, SelectionError> { ... } }

A database of installed fonts that can be queried.

This trait is object-safe.

Required Methods

Returns the names of all families installed on the system.

Looks up a font family by name and returns the handles of all the fonts in that family.

Provided Methods

Selects a font by PostScript name, which should be a unique identifier.

The default implementation, which is used by the DirectWrite and the filesystem backends, does a brute-force search of installed fonts to find the one that matches.

Performs font matching according to the CSS Fonts Level 3 specification and returns the handle.

Implementors