Struct font_kit::sources::fontconfig::FontconfigSource [−][src]
pub struct FontconfigSource { /* fields omitted */ }A source that contains the fonts installed on the system, as reported by the Fontconfig library.
On macOS and Windows, the Cargo feature source-fontconfig can be used to opt into fontconfig
support. To prefer it over the native font source (only if you know what you're doing), use the
source-fontconfig-default feature.
Methods
impl FontconfigSource[src]
impl FontconfigSourcepub fn new() -> FontconfigSource[src]
pub fn new() -> FontconfigSourceInitializes Fontconfig and prepares it for queries.
pub fn all_families(&self) -> Result<Vec<String>, SelectionError>[src]
pub fn all_families(&self) -> Result<Vec<String>, SelectionError>Returns the names of all families installed on the system.
pub fn select_family_by_name(
&self,
family_name: &str
) -> Result<FamilyHandle, SelectionError>[src]
pub fn select_family_by_name(
&self,
family_name: &str
) -> Result<FamilyHandle, SelectionError>Looks up a font family by name and returns the handles of all the fonts in that family.
pub fn select_by_postscript_name(
&self,
postscript_name: &str
) -> Result<Handle, SelectionError>[src]
pub fn select_by_postscript_name(
&self,
postscript_name: &str
) -> Result<Handle, SelectionError>Selects a font by PostScript name, which should be a unique identifier.
The default implementation, which is used by the DirectWrite and the filesystem backends, does a brute-force search of installed fonts to find the one that matches.
pub fn select_best_match(
&self,
family_names: &[FamilyName],
properties: &Properties
) -> Result<Handle, SelectionError>[src]
pub fn select_best_match(
&self,
family_names: &[FamilyName],
properties: &Properties
) -> Result<Handle, SelectionError>Performs font matching according to the CSS Fonts Level 3 specification and returns the handle.