Struct font_kit::sources::fs::FsSource [−][src]
pub struct FsSource { /* fields omitted */ }A source that loads fonts from a directory or directories on disk.
This source uses the WalkDir abstraction from the walkdir crate to locate fonts.
This is the native source on Android.
Methods
impl FsSource[src]
impl FsSourcepub fn new() -> FsSource[src]
pub fn new() -> FsSourceOpens the default set of directories on this platform and indexes the fonts found within.
Do not rely on this function for systems other than Android. It makes a best effort to locate fonts in the typical platform directories, but it is too simple to pick up fonts that are stored in unusual locations but nevertheless properly installed.
pub fn all_families(&self) -> Result<Vec<String>, SelectionError>[src]
pub fn all_families(&self) -> Result<Vec<String>, SelectionError>Returns the names of all families installed on the system.
pub fn select_family_by_name(
&self,
family_name: &str
) -> Result<FamilyHandle, SelectionError>[src]
pub fn select_family_by_name(
&self,
family_name: &str
) -> Result<FamilyHandle, SelectionError>Looks up a font family by name and returns the handles of all the fonts in that family.
pub fn select_by_postscript_name(
&self,
postscript_name: &str
) -> Result<Handle, SelectionError>[src]
pub fn select_by_postscript_name(
&self,
postscript_name: &str
) -> Result<Handle, SelectionError>Selects a font by PostScript name, which should be a unique identifier.
This implementation does a brute-force search of installed fonts to find the one that matches.
pub fn select_best_match(
&self,
family_names: &[FamilyName],
properties: &Properties
) -> Result<Handle, SelectionError>[src]
pub fn select_best_match(
&self,
family_names: &[FamilyName],
properties: &Properties
) -> Result<Handle, SelectionError>Performs font matching according to the CSS Fonts Level 3 specification and returns the handle.