Struct font_kit::sources::mem::MemSource [−][src]
pub struct MemSource { /* fields omitted */ }A source that keeps fonts in memory.
Methods
impl MemSource[src]
impl MemSourcepub fn from_fonts<I>(fonts: I) -> Result<MemSource, FontLoadingError> where
I: Iterator<Item = Handle>, [src]
pub fn from_fonts<I>(fonts: I) -> Result<MemSource, FontLoadingError> where
I: Iterator<Item = Handle>, Creates a new memory source that contains the given set of font handles.
The fonts referenced by the handles are eagerly loaded into memory.
pub fn all_families(&self) -> Result<Vec<String>, SelectionError>[src]
pub fn all_families(&self) -> Result<Vec<String>, SelectionError>Returns the names of all families installed on the system.
pub fn select_family_by_name(
&self,
family_name: &str
) -> Result<FamilyHandle, SelectionError>[src]
pub fn select_family_by_name(
&self,
family_name: &str
) -> Result<FamilyHandle, SelectionError>Looks up a font family by name and returns the handles of all the fonts in that family.
FIXME(pcwalton): Case-insensitive comparison.
pub fn select_by_postscript_name(
&self,
postscript_name: &str
) -> Result<Handle, SelectionError>[src]
pub fn select_by_postscript_name(
&self,
postscript_name: &str
) -> Result<Handle, SelectionError>Selects a font by PostScript name, which should be a unique identifier.
The default implementation, which is used by the DirectWrite and the filesystem backends, does a brute-force search of installed fonts to find the one that matches.
pub fn select_best_match(
&self,
family_names: &[FamilyName],
properties: &Properties
) -> Result<Handle, SelectionError>[src]
pub fn select_best_match(
&self,
family_names: &[FamilyName],
properties: &Properties
) -> Result<Handle, SelectionError>Performs font matching according to the CSS Fonts Level 3 specification and returns the handle.