Struct font_kit::sources::multi::MultiSource[][src]

pub struct MultiSource { /* fields omitted */ }

A source that encapsulates multiple sources and allows them to be queried as a group.

This is useful when an application wants a library of fonts consisting of the installed system fonts plus some other application-supplied fonts.

Methods

impl MultiSource
[src]

Creates a new source that contains all the fonts in the supplied sources.

Returns the names of all families installed on the system.

Looks up a font family by name and returns the handles of all the fonts in that family.

Selects a font by PostScript name, which should be a unique identifier.

Performs font matching according to the CSS Fonts Level 3 specification and returns the handle.