Struct font_kit::sources::multi::MultiSource [−][src]
pub struct MultiSource { /* fields omitted */ }A source that encapsulates multiple sources and allows them to be queried as a group.
This is useful when an application wants a library of fonts consisting of the installed system fonts plus some other application-supplied fonts.
Methods
impl MultiSource[src]
impl MultiSourcepub fn from_sources(subsources: Vec<Box<Source>>) -> MultiSource[src]
pub fn from_sources(subsources: Vec<Box<Source>>) -> MultiSourceCreates a new source that contains all the fonts in the supplied sources.
pub fn all_families(&self) -> Result<Vec<String>, SelectionError>[src]
pub fn all_families(&self) -> Result<Vec<String>, SelectionError>Returns the names of all families installed on the system.
pub fn select_family_by_name(
&self,
family_name: &str
) -> Result<FamilyHandle, SelectionError>[src]
pub fn select_family_by_name(
&self,
family_name: &str
) -> Result<FamilyHandle, SelectionError>Looks up a font family by name and returns the handles of all the fonts in that family.
pub fn select_by_postscript_name(
&self,
postscript_name: &str
) -> Result<Handle, SelectionError>[src]
pub fn select_by_postscript_name(
&self,
postscript_name: &str
) -> Result<Handle, SelectionError>Selects a font by PostScript name, which should be a unique identifier.
pub fn select_best_match(
&self,
family_names: &[FamilyName],
properties: &Properties
) -> Result<Handle, SelectionError>[src]
pub fn select_best_match(
&self,
family_names: &[FamilyName],
properties: &Properties
) -> Result<Handle, SelectionError>Performs font matching according to the CSS Fonts Level 3 specification and returns the handle.